#
# spec file for package kcm_tablet
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2010 Raymond Wooninck <tittiatcoke@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname wacomtablet
Name:           kcm_tablet
Version:        3.2.0
Release:        5.8
Summary:        KDE Config Module for Wacom Tablets
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://invent.kde.org/system/wacomtablet
Source:         https://download.kde.org/stable/%{rname}/%{version}/%{rname}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-build-with-Qt-5.15.patch
# PATCH-FIX-UPSTREAM
Patch1:         Check-for-index-validity-when-switching-tablet-type.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5GlobalAccel)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core) >= 5.7.0
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(libwacom)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xorg-wacom)
BuildRequires:  pkgconfig(xrandr)
Requires:       xf86-input-wacom >= 0.20
Recommends:     %{name}-lang = %{version}
Recommends:     xrandr >= 1.2
Supplements:    (plasma5-workspace and xf86-input-wacom)

%description
This module implements a GUI for the Wacom Linux Drivers and extends it
with profile support to handle different button / pen layouts per profile.

For hardware support have a look at http://www.linuxwacom.sourceforge.net

All tablets can be set up as long as they are found with the wacom kernel module.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %find_lang %{rname} %{name}.lang
  %find_lang plasma_applet_org.kde.plasma.%{rname} %{name}.lang
  %{kf5_find_htmldocs}

  %suse_update_desktop_file kde_wacom_tabletfinder HardwareSettings

%files lang -f %{name}.lang

%files
%license COPYING
%doc AUTHORS README.md
%doc %lang(en) %{_kf5_htmldir}/en/kcontrol
%{_kf5_applicationsdir}/kde_wacom_tabletfinder.desktop
%{_kf5_appstreamdir}/*.xml
%{_kf5_bindir}/kde_wacom_tabletfinder
%{_kf5_dbusinterfacesdir}/org.kde.Wacom*xml
%{_kf5_debugdir}/wacomtablet.categories
%{_kf5_notifydir}/wacomtablet.notifyrc
%{_kf5_plasmadir}/
%{_kf5_plugindir}/kcm_wacomtablet.so
%{_kf5_plugindir}/kf5/kded/wacomtablet.so
%dir %{_kf5_plugindir}/plasma/dataengine
%{_kf5_plugindir}/plasma/dataengine/plasma_engine_wacomtablet.so
%{_kf5_servicesdir}/kcm_wacomtablet.desktop
%if %{pkg_vcmp plasma-framework-devel < 5.84} || %{pkg_vcmp plasma-framework-devel > 5.89}
%{_kf5_servicesdir}/plasma-applet-org.kde.plasma.wacomtablet.desktop
%endif
%{_kf5_servicesdir}/plasma-dataengine-wacomtablet.desktop
%{_kf5_sharedir}/wacomtablet

%changelog
* Tue Dec 14 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix installation with plasma-framework 5.89.
* Thu Aug  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update the desktop file categories to fix the desktop-file-validate warnings.
* Sun Jul 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%files section. plasma-framework >= 5.84 doesn't install
  desktop files in %%_kf5_servicesdir anymore.
* Thu Apr 22 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL
* Wed Aug 12 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add patch to fix a possible crash in kde_wacom_tabletfinder
  (kde#423420, boo#1175126):
  * Check-for-index-validity-when-switching-tablet-type.patch
* Thu Jun  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
- Spec cleanup
* Sun Jul 28 2019 wbauer@tmo.at
- Update to version 3.2.0
- Main changes:
  * screen tablet area calculation fix (by Jason Gerecke); this
    should finally fix or at least greatly improve calibration.
  * GCC9 support.
  * xlib backend removed, x11-xlib dependency removed.
- New device definitions:
  * CTL-4100, CTL-4100WL, CTL-6100, CTL-6100WL (by Stefano Guidoni)
- Drop patches merged upstream:
  * 0001-Supposedly-fix-building-with-gcc9.patch
  * 0001-Remove-x11-xlib-dependency.patch
* Sat Jul  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build with cmake >= 3.14 (X11 never had an XLIB component):
  * 0001-Remove-x11-xlib-dependency.patch
* Mon May 27 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build with GCC 9:
  * 0001-Supposedly-fix-building-with-gcc9.patch
* Tue Dec 18 2018 wbauer@tmo.at
- Update to version 3.1.1
  * Some translation related fixes
* Sat Jun 23 2018 wbauer@tmo.at
- Update to version 3.1.0
- Major changes:
  * LibWacom support. This should get our number of supported
    tablets out of the box on par with GNOME. Right now built-in
    database and user-configured database still take preference
    over libwacom, but this should change in the future releases.
  * Calibration improvements: calibration of Cintiq devices should
    be vastly improved, UI now has options to lock mapped area
    proportions and manually fine-tune area's coordinates. Also,
    the dialog should now open on the correct screen and look fine
    with dark themes too.
  * Support for devices that report different USB IDs for
    touchscreen and may be detected as two different devices (e.g.
    Cintiq Companion Hybrid).
    These devices need to be described via Wacom Tablet finder
    tool first, though.
- Other changes:
  * Logging has been ported to QLoggingCategory (so now users have
    to enable it in kdebugsettings).
  * Status LED support improvements (Vangelis Tasoulas, Jason
    Gerecke).
  * Touchscreen rotation should now follow tablet rotation.
- New devices in built-in database:
  * Wacom Intuos Pro L (PTH-860, 2017) (Melvin Vermeeren)
  * Lenovo Yoga 520 (Felipe Abrahao)
  * ThinkPad Yoga 460 definition  (Albert Astals Cid)
  * Wacom Intuos Pro 2 M (Jeff H)
- Requires Qt 5.7.0 or higher now to compile successfully
* Wed Apr  4 2018 wbauer@tmo.at
- Update to version 3.0.0
  * Implemented hotplugging on Xlib (by Fabian Vogt). Hotplugging
    should now work on Debian/Ubuntu based distributions, and all
    other distributions that don't build libXCB with Xinput
    enabled.
  * Screen mapping configuration now uses output names instead of
    screen indices. This invalidates existing screen mapping
    configurations.
  * Tablet Finder should no longer skip button detection.
  * First steps in fixing rotation handling in multi-screen setup.
    However, for now if you want your screen rotation to be
    tracked, it has to be set as primary screen. Qt bug:
    https://bugreports.qt.io/browse/QTBUG-65598
  * Minor calibration dialog fixes. Calibration still might be off
    with Cintiq devices. Fixing those would require some feedback:
    https://userbase.kde.org/Wacomtablet#Calibration_issues_.26_manual_calibration
  * New device definitions:
    + Lenovo Yoga 520 (by Felipe Abrahao)
    + Wacom Intuos Pro L (PTH-860) (by Melvin Vermeeren)
    + Wacom Bamboo One M (CTL-671) (by Alexander)
- Drop Implement-hotplugging-on-Xlib.patch, merged upstream
- Mark license file as %%license
* Tue Jan 16 2018 fabian@ritter-vogt.de
- Add Supplements: packageand(plasma5-workspace:xf86-input-wacom)
- Run spec-cleaner
* Tue Jan  2 2018 wbauer@tmo.at
- Add Implement-hotplugging-on-Xlib.patch to make hotplugging work
  with Xlib too, without libxcb-xinput which we don't have yet
  (kde#361743)
* Sat Dec 30 2017 wbauer@tmo.at
- Update to version 2.9.82 (3.0.0 beta 2)
  * ported to KF5
  * This version has a few multi-screen fixes and couple of new device IDs.
    It also should no longer crash kded under wayland (however there's no
    actual wayland support yet).
    There are still two somewhat major issues: hotplug detection is not
    supported if libxcb doesn't have xinput support enabled (most likely
    affects Debian and Ubuntu), and screen rotation of non-mapped screens is
    not handled properly. Barring these, this beta should be stable enough
    for use in static setups and should be good enough to package.
- Moved english documentation into the main package
* Wed Feb 25 2015 aj@ajaissle.de
- Update to version 2.1.0
  * Add support for Cintiq 22HD 18 buttons
  * Add image for the Cintiq 13HD layout
  * Update Wacom Intuos PT S Finger touch device db entry
  * Update Intuous button layout
  * Update Wacom INTUOS Pen Small CTH-480 db entry (030E)
  * Add Wacom Intuos Pro L PTH-851 to db (0316)
  * Allow to setup Stylus/Eraser Tip Mosue button (Left-Handed Mode)
  * Update database. Add HUION, add Waltop again, install missing vendors
  * Implement support for multible tablets at once
  * Add simple dialog app to ease tablet detection and databse adding
  * Add global shortcut for profile rotation
  * Add status LED support for profile rotation (Intous/Chintiq)
  * Fix profile not found error on tablet connect
- v2.0.2
  * Fix compile error on older Qt versions (remove iconset="theme" stuff)
  * Add Raw Sample and Suppress to ui
- v2.0.1
  * More translations
  * Add Wacom Intuos Pro S / PTH-451/S
  * Add WacomIntuos Pen Small / CTL-480S tablet
  * Add definition of Wacom Intuos PT S / CTH-680S-RUPL
  * Add Wacom Intuos PT M / CTH-680S-ENES
  * Add support for Wacom Intuos Pro M / PTH-651
  * cmake: remove extra kio linking
  * adjusted control point and draw below curve area colors to be less websafe looking
  * Added Wacom Cintiq 13HD
  * Added Samsung Series 7 Slate
- Minor spec cleanups
* Sat Sep 28 2013 hrvoje.senjan@gmail.com
- Update to version 2.0
  Changes since 1.3:
  * Support for many new tablets.
  * Support for more global shortcuts.
  * Improved KCM GUI
  * Improved express button shortcut configuration.
  * Improved rotation handling.
  * Improved monitor and screen area mapping.
  * Improved backend.
  * Many bugfixes.
- Droped build_fix.diff, not needed.
- Added pkgconfig(xorg-wacom) BuildRequires
- lang package is built
- Small spec cleanup
- Adjusted license
* Fri Jan 28 2011 wstephenson@novell.com
- Update to version 1.2.5
  * really small fix with the TwinView horizontal/vertical selection
- Update to version 1.2.4
  * fixed detection of the CTL-460
  * changed usage of button settings. Should work with new
    xsetwacom driver and thus get rid of the tablet drag and draw error
- Update to version 1.2.3b
  * fixed a small bug that crashes the kded
- Update to version 1.2.3
  * detection of the tablets completely changed, instead of solid
    and cmd parsing the detection is now based on XInput libs
  * several bugfixes
  * some smaller changes in the plasma applet
  * included .po files for some languages
  * added support for the Lenovo X201 tablet
- Update to version 1.2.2
  * several bugfixes
- Update to version 1.2.1
  * added support for Wacom BambooFun 2FG 4x5 and Wacom Intuos4 4x6
  * Fix mem leak
* Fri Mar  5 2010 tittiatcoke@gmail.com
- Update to version 1.2
  * splitted module into kcmodule, kded deamon and a plasma applet
  * daemon now supports hotplug support and applies profiles on startup
  without the need to open the kcmodule
  * applet allows to switch profiles easily
  * changed keyshortcut selection
  * added german translation
  * some smaller bugfixes
* Wed Feb  3 2010 tittiatcoke@gmail.com
- Initial release, version 1.1.3
